summaryrefslogtreecommitdiffstats
path: root/kbruch/src/taskwidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kbruch/src/taskwidget.cpp
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbruch/src/taskwidget.cpp')
-rw-r--r--kbruch/src/taskwidget.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kbruch/src/taskwidget.cpp b/kbruch/src/taskwidget.cpp
index 1807283e..795bc4cb 100644
--- a/kbruch/src/taskwidget.cpp
+++ b/kbruch/src/taskwidget.cpp
@@ -21,12 +21,12 @@
/* these includes are needed for KDE support */
#include <klocale.h>
/* these includes are needed for Qt support */
#include <tqpainter.h>
-TaskWidget::TaskWidget(TQWidget * parent = 0, const char * name = 0,
+TaskWidget::TaskWidget(TQWidget * tqparent = 0, const char * name = 0,
const task para_task = *new task()) :
- FractionBaseWidget(parent, name), m_task(para_task)
+ FractionBaseWidget(tqparent, name), m_task(para_task)
{
#ifdef DEBUG
kdDebug() << "constructor TaskWidget" << endl;
@@ -65,7 +65,7 @@ void TaskWidget::paintEvent(TQPaintEvent* /* p_paintEvent */)
paint.setFont(m_font);
// set the pen for painting
- TQPen pen(Qt::SolidLine);
+ TQPen pen(TQt::SolidLine);
pen.setWidth(0);
paint.setPen(pen);
@@ -21,12 +21,12 @@
/* these includes are needed for KDE support */
#include <klocale.h>
-/* these includes are needed for Qt support */
+/* these includes are needed for TQt support */
#include <tqpainter.h>